"""This module defines the FastAPI healthcheck router"""
from fastapi import APIRouter, HTTPException

from pq_dashboard.config import settings
from pq_dashboard.connection import get_connection

router = APIRouter(prefix="/health", tags=["health"])


@router.get("/check")
async def health_check():
    """Health check endpoint"""
    connection = None
    try:
        connection = get_connection()
        return {"still": "alive"}
    except Exception:
        raise HTTPException(status_code=500, detail="Cannot connect to database")
    finally:
        if connection:
            connection.close()


@router.get("/config")
async def config():
    """Get current configuration"""
    data = settings.dict()
    data.pop("PGPASSWORD", None)

    return data



"""This module contains configuration logic using environment variables
for the pq-dashboard application"""
from pydantic import BaseSettings


class Settings(BaseSettings):
    """
    Settings for pq-dashboard. All can be edited by defining
    environment variables prefixed with PQ_DASH_.
    ex PQ_DASH_DB_HOST to change the postgres server location
    """

    PGHOST: str = "localhost"
    PGPORT: int = 5432
    PGUSER: str = "postgres"
    PGPASSWORD: str = "postgres"
    DATABASE: str = "postgres"
    QUEUE_TABLE: str = "queue"

    class Config:
        env_prefix = "PQ_DASH_"


settings = Settings(_env_file=".pq-dash.env")



"""This module contains the FastAPI router used for manipulating queues"""
from fastapi import APIRouter, Depends, Response, status

from pq_dashboard.connection import get_cursor
from pq_dashboard.data.queues import (
    delete_processed_items,
    delete_queued_items,
    get_queue_stats,
)

router = APIRouter(prefix="/queues", tags=["queues"])


@router.get("/")
async def queues(cursor=Depends(get_cursor)):
    """Retrieve queue statistics"""
    return get_queue_stats(cursor)


@router.post("/{queue_name}/delete-queued")
async def delete_queued(queue_name: str, cursor=Depends(get_cursor)):
    """Delete all items from the queue with the given name"""
    delete_queued_items(cursor, queue_name)

    return Response(status_code=status.HTTP_200_OK)


@router.post("/{queue_name}/delete-processed")
async def delete_processed(queue_name: str, cursor=Depends(get_cursor)):
    """Delete all processed items from the queue with the given name"""
    delete_processed_items(cursor, queue_name)

    return Response(status_code=status.HTTP_200_OK)



"""This module contains the FastAPI router used for manipulating queue items"""
from typing import Optional

from fastapi import APIRouter, Depends

from pq_dashboard.connection import get_cursor
from pq_dashboard.data.items import (
    delete_item,
    get_item_counts,
    get_items,
    requeue_item,
)
from pq_dashboard.schema.item import ItemPage

router = APIRouter(prefix="/items", tags=["items"])


@router.get("/")
async def items(
    cursor=Depends(get_cursor),
    limit: int = 10,
    offset: int = 0,
    queue: Optional[str] = None,
    exclude_processed: Optional[bool] = None,
    search: Optional[str] = None,
    order_by: Optional[str] = None,
):
    """Retrieve a list of items from the queue specified by the given parameters

    Kwargs:
        limit: Result pagination limit
        offset: Result pagination offset
        queue: Queue to filter items from. Default is None (all queues)
        exclude_processed: Filter out processed items when True
        order_by: Order results by
        search: Filter only for items matching term
    """
    records = get_items(
        cursor,
        limit=limit,
        offset=offset,
        queue_name=queue,
        exclude_processed=exclude_processed,
        search=search,
        order_by=order_by,
    )
    totals = get_item_counts(cursor, queue_name=queue, search=search)

    if exclude_processed:
        total = totals["queued"]
    else:
        total = totals["total"]

    return ItemPage(records=records, limit=limit, offset=offset, total=total)


@router.delete("/{item_id}")
async def delete(item_id: int, cursor=Depends(get_cursor)):
    delete_item(cursor, item_id)


@router.post("/{item_id}/requeue")
async def requeue(item_id: int, cursor=Depends(get_cursor)):
    requeue_item(cursor, item_id)



"""This module contains helper methods for working with queues"""
from typing import Dict, List

from pq_dashboard.config import settings
from pq_dashboard.schema.queue import Queue


def get_queue_stats(cursor) -> List[Queue]:
    """Get a list of Queue objects

    Args:
        cursor ([type]): psycopg2 cursor

    Returns:
        List[Queue]: List of Queue statistics objects
    """
    cursor.execute(
        f"SELECT q_name, (dequeued_at IS NOT NULL) AS dequeued, COUNT(dequeued_at IS NOT NULL) FROM {settings.QUEUE_TABLE} GROUP BY q_name, dequeued"
    )
    results = cursor.fetchall()

    raw_queues_by_name: Dict[str, dict] = {}
    lookup = {True: "processed", False: "queued"}

    for name, item_type, count in results:
        raw_queues_by_name.setdefault(name, {})[lookup[item_type]] = count

    return [
        Queue(
            name=name,
            total=(value.get("processed", 0) + value.get("queued", 0)),
            **value,
        )
        for name, value in raw_queues_by_name.items()
    ]


def delete_queued_items(cursor, queue_name: str):
    """Delete all currently-queued items from a queue

    Args:
        cursor: DB cursor
        queue_name (str): Name of queue to empty
    """
    cursor.execute(
        f"DELETE FROM {settings.QUEUE_TABLE} WHERE q_name = %s AND dequeued_at IS NULL",
        (queue_name,),
    )
    cursor.connection.commit()


def delete_processed_items(cursor, queue_name: str):
    """Delete all processed (processed) items from a queue

    Args:
        cursor: DB cursor
        queue_name (str): Name of queue to cleanup items from
    """
    cursor.execute(
        f"DELETE FROM {settings.QUEUE_TABLE} WHERE q_name = %s AND dequeued_at IS NOT NULL",
        (queue_name,),
    )
    cursor.connection.commit()



"""This module contains pydantic models for working with Queues"""
from pydantic import BaseModel, Field


class Queue(BaseModel):
    name: str
    total: int
    queued: int = Field(0)
    processed: int = Field(0)



"""Entrypoint script for invoking pq-dashboard on the command line"""
import argparse
import sys

import psycopg2

from pq_dashboard.cli.commands import cancel_all, cleanup, show_stats, start_dashboard


def get_parser() -> argparse.ArgumentParser:
    """Build a parser for CLI flags to the dashboard"""
    parser = argparse.ArgumentParser(
        "pq-dashboard",
        description="Web dashboard and CLI utility for managing PQ queues",
    )

    parser.add_argument(
        "--host", help="IP or hostname for server (default: 0.0.0.0)", default="0.0.0.0"
    )
    parser.add_argument(
        "--port", help="Port for server to listen on (default: 9182)", default=9182
    )

    subparsers = parser.add_subparsers(help="CLI help", dest="subcommand")

    stats_subparser = subparsers.add_parser("stats", help="Show queue statistics")
    stats_subparser.add_argument(
        "stats_queue_names",
        nargs="?",
        help="Comma-separated list of queue names to show stats for (optional, default is all queues)",
    )

    cleanup_subparser = subparsers.add_parser(
        "cleanup", help="Cleanup processed items from one-or-more queues"
    )
    cleanup_subparser.add_argument(
        "cleanup_queue_names",
        nargs="+",
        help="Comma-separated list of queue names to cleanup processed items from",
    )

    cancel_all_subparser = subparsers.add_parser(
        "cancel-all",
        help="Cancel queued items from one-or-more queues",
    )
    cancel_all_subparser.add_argument(
        "cancel_queue_names",
        nargs="+",
        help="Comma-separated list of queue names to cleanup processed items from",
    )

    return parser


def main():
    """Entrypoint (see pyproject.toml)"""
    parser = get_parser()

    flags = parser.parse_args()

    try:
        if flags.subcommand == None:
            start_dashboard(**vars(flags))
        elif flags.subcommand == "stats":
            show_stats(**vars(flags))
        elif flags.subcommand == "cleanup":
            cleanup(**vars(flags))
        elif flags.subcommand == "cancel-all":
            cancel_all(**vars(flags))
    except psycopg2.OperationalError as err:
        print()
        print(f"Error: Unable to connect to Postgres")
        print()
        print(err)
        print("Check your configuration")
        sys.exit(1)



"""This module contains helper methods for working with items"""
import json
import pickle
from typing import Dict, List

from pq_dashboard.config import settings
from pq_dashboard.schema.item import Item


def get_item_counts(
    cursor, queue_name: str = None, search: str = None
) -> Dict[str, int]:
    """Get count of queued, processed and total items"""
    statement = f"SELECT (dequeued_at IS NOT NULL) AS dequeued, COUNT(dequeued_at IS NOT NULL) FROM {settings.QUEUE_TABLE}"
    parameters = []

    where_clauses = []

    if queue_name is not None:
        where_clauses.append("q_name = %s")
        parameters.append(queue_name)

    if search is not None:
        search = search.replace("=", "==").replace("%", "=%").replace("_", "=_")
        where_clauses.append("data::TEXT ILIKE %s ESCAPE '='")
        parameters.append("%" + search + "%")

    if len(where_clauses) > 0:
        where_clause = " WHERE " + " AND ".join(where_clauses)
    else:
        where_clause = ""

    statement += where_clause
    statement += " GROUP BY dequeued"

    cursor.execute(statement, tuple(parameters))

    results = cursor.fetchall()

    labels = {True: "processed", False: "queued"}

    response = {labels[state]: count for state, count in results}

    response["total"] = sum(response.values())

    return response


def get_order_by_clause(order_by=None):
    """
    Helper method to build an ordering clause based on
    selected ordering from the frontend
    """
    ordering = {
        "enqueuedAt_ASC": " enqueued_at ASC ",
        "enqueuedAt_DESC": " enqueued_at DESC ",
        "dequeuedAt_ASC": "dequeued_at ASC",
        "dequeuedAt_DESC": "dequeued_at DESC",
        "expectedAt_ASC": "expected_at ASC",
        "expectedAt_DESC": "expected_at DESC",
        "scheduledAt_ASC": "scheduled_at ASC",
        "scheduledAt_DESC": "scheduled_at DESC",
        "queue_ASC": "q_name ASC",
        "queue_DESC": "q_name DESC",
    }.get(order_by, "enqueued_at ASC")

    return f" ORDER BY {ordering} LIMIT %s OFFSET %s"


def get_items(
    cursor,
    limit=25,
    offset=0,
    queue_name=None,
    exclude_processed=False,
    search=None,
    order_by=None,
) -> List[Item]:
    """Get queue items

    Args:
        cursor: DB cursor
        limit (int, optional): How many items to fetch. Defaults to 25.
        offset (int, optional): How many items to skip fetching. Defaults to 0.

    Returns:
        List[Item]: Items retrieved from the relevant queue table
    """
    select_clause = f"SELECT id, enqueued_at, dequeued_at, expected_at, schedule_at, q_name, data FROM {settings.QUEUE_TABLE}"
    params = []

    where_clauses = []

    if queue_name is not None:
        where_clauses.append("q_name = %s")
        params.append(queue_name)

    if exclude_processed == True:
        where_clauses.append("dequeued_at IS NULL")

    if search is not None:
        search = search.replace("=", "==").replace("%", "=%").replace("_", "=_")
        where_clauses.append("data::TEXT ILIKE %s ESCAPE '='")
        params.append("%" + search + "%")

    order_by_clause = get_order_by_clause(order_by)
    params.extend([limit, offset])

    if len(where_clauses) > 0:
        where_clause = " WHERE " + " AND ".join(where_clauses)
    else:
        where_clause = ""

    cursor.execute(
        select_clause + where_clause + order_by_clause,
        tuple(params),
    )

    items = []
    for object in cursor.fetchall():

        if isinstance(object["data"], str):
            # data is a string for PQ's pickled queues.
            # In this case we try to deserialize using pickle
            try:
                object["data"] = pickle.loads(object["data"].encode("latin-1"))
            except pickle.UnpicklingError as err:
                # We assume the fact it's an invalid pickle means it's an ordinary string
                pass

        if isinstance(object["data"], bytes):
            try:
                object["data"] = pickle.loads(object["data"])
            except pickle.UnpicklingError as err:
                object["data"] = "<unknown binary data>"

        items.append(Item(**object))

    return items


def delete_item(cursor, item_id: int):
    """Delete an item from the queue by its ID

    Args:
        cursor: DB cursor
        item_id (int): ID of the item to delete
    """
    cursor.execute(f"DELETE FROM {settings.QUEUE_TABLE} WHERE id = %s", (item_id,))
    cursor.connection.commit()


def requeue_item(cursor, item_id: int):
    """Requeue an item by its ID

    Args:
        cursor: DB cursor
        item_id (int): ID of the item to requeue
    """
    cursor.execute(
        f"SELECT q_name, data FROM {settings.QUEUE_TABLE} WHERE id = %s", (item_id,)
    )

    result = cursor.fetchone()

    cursor.execute(
        f"INSERT INTO {settings.QUEUE_TABLE}(q_name, data) VALUES(%s, %s)",
        (result[0], json.dumps(result[1])),
    )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pq_dashboard',
 'pq_dashboard.cli',
 'pq_dashboard.data',
 'pq_dashboard.routers',
 'pq_dashboard.schema']

package_data = \
{'': ['*'],
 'pq_dashboard': ['frontend/*',
                  'frontend/www/*',
                  'frontend/www/assets/.gitkeep',
                  'frontend/www/assets/.gitkeep',
                  'frontend/www/assets/.gitkeep',
                  'frontend/www/assets/ReactToastify.css',
                  'frontend/www/assets/ReactToastify.css',
                  'frontend/www/assets/ReactToastify.css',
                  'frontend/www/assets/favicon.png',
                  'frontend/www/assets/favicon.png',
                  'frontend/www/assets/favicon.png']}

install_requires = \
['aiofiles>=0.7.0,<0.8.0',
 'fastapi>=0.67.0,<0.68.0',
 'psycopg2>=2.9.1,<3.0.0',
 'pydantic>=1.8.2,<2.0.0',
 'pytest-postgresql>=3.1.1,<4.0.0',
 'uvicorn[standard]>=0.14.0,<0.15.0']

entry_points = \
{'console_scripts': ['pq-dashboard = pq_dashboard.cli:main']}

setup_kwargs = {
    'name': 'pq-dashboard',
    'version': '0.1.0',
    'description': 'Web dashboard and CLI utility for managing PQ queues',
    'long_description': '# pq-dashboard\n\n`pq-dashboard` is a general purpose, lightweight, [FastAPI](https://fastapi.tiangolo.com/)-based web front-end and CLI tool to monitor your [PQ](https://github.com/malthe/pq/) queues and tasks.\n\n[Sound familiar?](https://github.com/Parallels/rq-dashboard#introduction) Basically, `pq-dashboard` is to `pq` as `rq-dashboard` is to `rq`.\n\n## Quickstart\n\n### Installing from PyPI\n\n`python -m pip install pq-dashboard`\n\nThen run `pq-dashboard` with no arguments, which will start the server.\n\n```\n$ pq-dashboard\n```\n\nYou may need to configure environment variables (see below) to connect to the PostGRES server where your `pq` queues are stored.\n\n### Using docker\n\n`pq-dashboard` can run as a docker container. The image can be built with `./scripts/build-image.sh`. This creates the `pq-dashboard:v0` image.\n\nThe easiest way to run locally is to use the host network:\n\n```\ndocker run --net=host pq-dashboard:v0\n```\n\nThe app will then be available on host port `9182` by default. In production, you may want to configure networking differently.\n\nAn environment file can be passed to `docker` like this:\n\n```\ndocker run --env-file=.pq-dash.env --net=host pq-dashboard:v0\n```\n\n### CLI tool usage\n\nThe `pq-dashboard` command can also be used as a CLI tool for basic queue management.\n\n```\n$ pq-dashboard stats|cleanup|cancel-all <comma-separated list of queue names>\n```\n\nFor more details, see the help messages on all the commands\n\n## Environment variables\n\n`pq-dashboard` will read config from environment variables prefixed with `PQ_DASH`.\n\n| Variable                   | Default value | Explanation                                     |\n| -------------------------- | ------------- | ----------------------------------------------- |\n| `PQ_DASH_PGHOST`           | `localhost`   | Host the PostgreSQL server is running on.       |\n| `PQ_DASH_PGPORT`           | `5432`        | Port the PostgreSQL server is running on.       |\n| `PQ_DASHBOARD_PGUSER`      | `postgres`    | PostgreSQL user name to connect as.             |\n| `PQ_DASHBOARD_PGPASSWORD`  | `postgres`    | Password for the PostgreSQL user.               |\n| `PQ_DASHBOARD_DATABASE`    | `postgres`    | PostgreSQL database name containing queue table |\n| `PQ_DASHBOARD_QUEUE_TABLE` | `queue`       | Name of queue table containing items            |\n\nAlternatively, these variables can be stored in a plaintext `.pq-dash.env` file. Enviroment variables\nwill take precedence over the `.env` file.\n\n## Development\n\nTo install dev dependencies, use:\n\n```\npoetry install\n```\n\nThen, install the [`pre-commit`](https://pre-commit.com/) hook:\n\n```\npre-commit install\n```\n\nThis ensures all commits will be linted properly.\n\nTo run the dev frontend, from the `pq_dashboard/frontend` directory run:\n\n```\nnpm run dev\n```\n\nthen to start the backend:\n\n```\nuvicorn pq_dashboard.main:app --reload --port 9182\n```\n\nThe backend statically serves the frontend, but you will need to refresh the page to see your changes in the frontend code.\n',
    'author': 'Tom Keefe',
    'author_email': '8655118+MisterKeefe@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/MisterKeefe/pq-dashboard',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



"""This module contains command functions invoked by the CLI"""
from typing import List

import uvicorn

from pq_dashboard.connection import cursor_manager
from pq_dashboard.data.queues import (
    delete_processed_items,
    delete_queued_items,
    get_queue_stats,
)


def start_dashboard(host="0.0.0.0", port=9182, **kwargs):
    """Start the dashboard server"""
    print(
        f"Starting \x1b[1;38;5;14mpq-dashboard\x1b[0m on \x1b[1m{host}:{port}\x1b[0m..."
    )
    uvicorn.run("pq_dashboard.main:app", host=host, port=port, log_level="error")


def show_stats(stats_queue_names, **kwargs):
    """Prints a table of queue statistics to STDOUT"""
    stats_queue_names = (
        stats_queue_names.split(",") if stats_queue_names is not None else []
    )

    with cursor_manager() as cursor:
        data = get_queue_stats(cursor)

    if stats_queue_names:
        data = [queue for queue in data if queue.name in stats_queue_names]

    if len(data) == 0:
        print()
        print(f"  no queues matched: \x1b[1m{stats_queue_names}\x1b[0m")
        return

    max_name_length = (
        max([len(queue.name) for queue in data]) if len(data) > 1 else len(data[0].name)
    ) + 2

    SEP = "\x1b[38;5;7m╎\x1b[0m"

    header_format = (
        f"{SEP}{{:^{max_name_length}}}{SEP}{{:^10}}{SEP}{{:^11}}{SEP}{{:^10}}{SEP}"
    )
    row_format = (
        f"{SEP}{{:^{max_name_length}}}{SEP}{{:^10}}{SEP}{{:^11}}{SEP}{{:^10}}{SEP}"
    )

    header_text = header_format.format("Name", "Queued", "Processed", "Total")

    rows = []
    rows.append(
        "\x1b[38;5;7m"
        + "┌"
        + ("╌" * max_name_length)
        + "┬"
        + ("╌" * 10)
        + "┬"
        + ("╌" * 11)
        + "┬"
        + ("╌" * 10)
        + "┐"
        + "\x1b[0m"
    )
    rows.append(header_text)
    rows.append(
        "\x1b[38;5;7m"
        + "├"
        + ("╌" * max_name_length)
        + "┼"
        + ("╌" * 10)
        + "┼"
        + ("╌" * 11)
        + "┼"
        + ("╌" * 10)
        + "┤"
        + "\x1b[0m"
    )
    rows.extend(
        row_format.format(queue.name, queue.queued, queue.processed, queue.total)
        for queue in data
    )
    rows.append(
        "\x1b[38;5;7m"
        + "└"
        + ("╌" * max_name_length)
        + "┴"
        + ("╌" * 10)
        + "┴"
        + ("╌" * 11)
        + "┴"
        + ("╌" * 10)
        + "┘"
        + "\x1b[0m"
    )

    print()
    for row in rows:
        print("  " + row)


def cleanup(cleanup_queue_names, **kwargs):
    """Cleanup all processed tasks from the given queues

    Args:
        cleanup_queue_names: Comma-separated queues to clean
    """
    cleanup_queue_names = cleanup_queue_names[0].split(",")

    with cursor_manager() as cursor:
        data = get_queue_stats(cursor)
        data = {queue.name: queue for queue in data}

        print()

        for queue_name in cleanup_queue_names:
            if queue_name in data:
                delete_processed_items(cursor, queue_name)
                print(
                    f"  Cleaned up \x1b[1m{data[queue_name].processed}\x1b[0m processed items from queue \x1b[1m{queue_name}\x1b[0m"
                )
            else:
                print(f"Unknown queue: {queue_name}")


def cancel_all(cancel_queue_names, **kwargs):
    """Cancel all queued tasks from the given queues

    Args:
        cancel_queue_names: Comma-separated queues to cancel tasks from
    """
    cancel_queue_names = cancel_queue_names[0].split(",")

    with cursor_manager() as cursor:
        data = get_queue_stats(cursor)
        data = {queue.name: queue for queue in data}

        print()

        for queue_name in cancel_queue_names:
            if queue_name in data:
                delete_queued_items(cursor, queue_name)
                print(
                    f"  Cancelled all \x1b[1m{data[queue_name].queued}\x1b[0m queued items from queue \x1b[1m{queue_name}\x1b[0m"
                )
            else:
                print(f"Unknown queue: {queue_name}")



"""This module contains pydantic models for working with Items"""
from datetime import datetime
from typing import List, Optional, Union

from pydantic import BaseModel


class Item(BaseModel):
    """Pydantic model for a pq queue item"""

    id: int
    enqueued_at: datetime
    dequeued_at: Optional[datetime]
    expected_at: Optional[datetime]
    schedule_at: Optional[datetime]
    q_name: str
    data: Union[dict, list, str]


class ItemPage(BaseModel):
    """Pydantic model for a list of items"""

    records: List[Item]
    total: int
    limit: int
    offset: int



"""This module contains utilities for interacting with the database"""
from contextlib import contextmanager

from psycopg2 import connect
from psycopg2.extras import DictCursor

from pq_dashboard.config import settings


def get_connection():
    """Utility function for connecting to Postgres"""
    connection = connect(
        database=settings.DATABASE,
        user=settings.PGUSER,
        password=settings.PGPASSWORD,
        host=settings.PGHOST,
        port=settings.PGPORT,
        cursor_factory=DictCursor,
    )

    return connection


def get_cursor():
    """FastAPI DI function for getting a DB cursor which cleans up after itself"""
    connection = get_connection()
    cursor = connection.cursor()

    yield cursor

    connection.commit()
    cursor.close()
    connection.close()


@contextmanager
def cursor_manager():
    """Standalone ContextManager variation of get_cursor for CLI scripts"""
    yield from get_cursor()



"""This module defines the main FastAPI app"""
from functools import lru_cache
from pathlib import Path

import psycopg2
from fastapi import Depends, FastAPI, Request
from fastapi.responses import HTMLResponse, JSONResponse
from fastapi.staticfiles import StaticFiles

from pq_dashboard.routers import health, items, queues

app = FastAPI()


@lru_cache(maxsize=1)
def get_homepage_contents():
    with open(
        Path(__file__).parent / "frontend" / "www" / "index.html"
    ) as homepage_file:
        return homepage_file.read()


@app.get("/")
async def home(page=Depends(get_homepage_contents)):
    return HTMLResponse(page, status_code=200)


app.mount(
    "/assets",
    StaticFiles(directory=Path(__file__).parent / "frontend" / "www" / "assets"),
    name="assets",
)

# We prefix all API routes with `/api/v1`
# to make things cleaner on the FE
v1_api = FastAPI()


@v1_api.exception_handler(psycopg2.OperationalError)
async def db_exception_handler(request: Request, exc: psycopg2.OperationalError):
    """Exception handler for incorrectly configured database"""
    return JSONResponse(
        status_code=418,
        content={
            "message": f"Unable to connect to database. Your configuration may be incorrect"
        },
    )


v1_api.include_router(items.router)
v1_api.include_router(queues.router)
v1_api.include_router(health.router)

app.mount("/api/v1", v1_api)
